import React, { useEffect, useMemo, useRef, useState } from 'react';
import { Modal, Button } from 'antd';
import useMap from './map';
import { useMarker, useMarkerVisible } from './marker';
import Styles from './style.less';
import RadioGroup from '../ScreenBox/Radio/RadioGroup';

export default (props) => {
  const { machineTypeList, orgList, machineList } = props;

  const container = useRef();
  const currentMachineRef = useRef();
  const [machineType, setMachineType] = useState('t0');
  const [isModalVisible, setIsModalVisible] = useState(false);

  // 修改地图的默认样式
  useEffect(() => {
    const t = setInterval(() => {
      const el = document.querySelector('.amap-ctrl-zoomin');
      if (el) {
        clearInterval(t);
        el.style.color = '#fff';
        document.querySelector('.amap-ctrl-zoomout').style.color = '#fff';
      }
    }, 500);

    return () => clearInterval(t);
  }, []);

  // 构造地图
  const { amapRef, map } = useMap(container);

  // 把合作社跟农机合并到一起, 合作社的 typeId 设置为 t0
  const list = useMemo(() => {
    // org 没有 typeId, 因此所有 org 的节点都会带有 typeId = 't0'
    return (orgList || []).map((item) => ({ typeId: 't0', ...item })).concat(machineList || []);
  }, [orgList, machineList]);

  // 生成所有的 marker
  const markerListRef = useMarker(amapRef, map, list);
  // 监听选择
  useMarkerVisible(map, markerListRef, machineType);

  // 把农机 marker 的点击事件挂载到 window 下面作为全局 function
  useEffect(() => {
    if (!machineList || !machineList.length) return;

    window.openVideo = function (machineryId) {
      currentMachineRef.current = machineList.filter((x) => x.machineryId === machineryId)[0];
      setIsModalVisible(true);
    };

    return () => (window.openVideo = undefined);
  }, [machineList]);

  return (
    <div className={Styles['geo-map-container']}>
      <RadioGroup
        className={Styles['radio-group']}
        list={machineTypeList}
        value={machineType}
        onChange={setMachineType}
      />

      {/* 占位图片 */}
      <div className={Styles['geo-map-header']}>
        <div />
        <div />
        <div />
      </div>

      <div className={Styles['geo-map-body']}>
        {/* 渲染地图 */}
        <div ref={container} />
      </div>

      {/* 占位图片 */}
      <div className={Styles['geo-map-footer']}>
        <div />
        <div />
        <div />
      </div>
      <Modal
        title="农机监控"
        footer={null}
        visible={isModalVisible}
        onCancel={() => setIsModalVisible(false)}
      >
        <video
          width="320"
          height="240"
          controls
          src="https://www.runoob.com/try/demo_source/movie.mp4"
        >
          <source src="movie.mp4" type="video/mp4" />
          <source src="movie.ogg" type="video/ogg" />
          您的浏览器不支持 video 。
        </video>
      </Modal>
    </div>
  );
};
